----
title: Introduction to ImandraX
description: Introduction to IML and ImandraX
order: 1
----

IML (Imandra Modeling Language)
- syntax: a formalized Higher-Order subset of OCaml extended with theorem proving
tactics and verification annotations
- features: counter-example generation, automated induction, conditional rewriting,
bounded and unbounded verification, theorem proving, model checking, lemma discovery
- logic: Computational Higher-Order Logic (HOL) based on a pure subset of OCaml.
Recursion and Induction based on ordinals up to ε_0.
